# Generated by roxygen2: do not edit by hand

export(add_worms_taxonomy)
export(assign_phytoplankton_group)
export(calc_zooplankton_biomass)
export(calc_zooplankton_dry_weight)
export(check_Bacterioplankton)
export(check_Chlorophyll)
export(check_Epibenthos)
export(check_EpibenthosDropvideo)
export(check_GreySeal)
export(check_HarbourPorpoise)
export(check_HarbourSeal)
export(check_PhysicalChemical)
export(check_Phytoplankton)
export(check_Picoplankton)
export(check_PrimaryProduction)
export(check_RingedSeal)
export(check_SealPathology)
export(check_Sedimentation)
export(check_Zoobenthos)
export(check_Zooplankton)
export(check_bacterial_carbon)
export(check_bacterial_concentration)
export(check_bacterial_production)
export(check_chlorophyll_conc)
export(check_code_proj)
export(check_codes)
export(check_datatype)
export(check_deliv_Bacterioplankton)
export(check_deliv_Chlorophyll)
export(check_deliv_Epibenthos)
export(check_deliv_EpibenthosDropvideo)
export(check_deliv_GreySeal)
export(check_deliv_HarbourPorpoise)
export(check_deliv_HarbourSeal)
export(check_deliv_PhysicalChemical)
export(check_deliv_Phytoplankton)
export(check_deliv_Picoplankton)
export(check_deliv_PrimaryProduction)
export(check_deliv_RingedSeal)
export(check_deliv_SealPathology)
export(check_deliv_Sedimentation)
export(check_deliv_Zoobenthos)
export(check_deliv_Zooplankton)
export(check_depth)
export(check_epibenthos_abundclass_logical)
export(check_epibenthos_counted)
export(check_epibenthos_cover_logical)
export(check_epibenthos_coverclass_logical)
export(check_epibenthos_coverpercent_logical)
export(check_epibenthos_dryweight)
export(check_epibenthos_sedimentdepos_logical)
export(check_epibenthos_specdistr_maxdepth)
export(check_epibenthos_specdistr_mindepth)
export(check_epibenthos_totcover_logical)
export(check_fields)
export(check_greyseal_counted)
export(check_harbourseal_counted)
export(check_harbporp_positivemin)
export(check_logical_parameter)
export(check_nominal_station)
export(check_onland)
export(check_outliers)
export(check_parameter_rules)
export(check_phytoplankton_abund)
export(check_phytoplankton_biovol)
export(check_phytoplankton_carbon)
export(check_phytoplankton_counted)
export(check_picoplankton_abundance)
export(check_picoplankton_biovol)
export(check_picoplankton_carbon)
export(check_picoplankton_counted)
export(check_primaryproduction_carbonprod)
export(check_primaryproduction_carbonprod_hour)
export(check_primaryproduction_carbonprodlight)
export(check_ringedseal_calccounted)
export(check_setup)
export(check_station_distance)
export(check_value_logical)
export(check_zero_positions)
export(check_zero_value)
export(check_zoobenthos_BQIm)
export(check_zoobenthos_BQIm_logical)
export(check_zoobenthos_abund)
export(check_zoobenthos_counted)
export(check_zoobenthos_wetweight)
export(check_zoobenthos_wetweight_logical)
export(check_zooplankton_abund)
export(check_zooplankton_carbon)
export(check_zooplankton_counted)
export(check_zooplankton_length_mean)
export(check_zooplankton_length_median)
export(check_zooplankton_wetweight)
export(check_zooplankton_wetweight_area)
export(check_zooplankton_wetweight_volume)
export(clean_shark4r_cache)
export(construct_dyntaxa_table)
export(convert_ddmm_to_dd)
export(create_pie_map)
export(find_required_fields)
export(get_algaebase_genus)
export(get_algaebase_species)
export(get_delivery_template)
export(get_dyntaxa_dwca)
export(get_dyntaxa_parent_ids)
export(get_dyntaxa_records)
export(get_hab_list)
export(get_nomp_list)
export(get_nua_external_links)
export(get_nua_harmfulness)
export(get_nua_image_labeling_links)
export(get_nua_image_labeling_metadata)
export(get_nua_media_links)
export(get_nua_media_metadata)
export(get_nua_taxa)
export(get_peg_list)
export(get_shark_codes)
export(get_shark_data)
export(get_shark_datasets)
export(get_shark_options)
export(get_shark_statistics)
export(get_shark_table_counts)
export(get_toxin_list)
export(get_worms_classification)
export(get_worms_records)
export(get_worms_records_name)
export(get_worms_taxonomy_tree)
export(ifcb_is_near_land)
export(ifcb_which_basin)
export(is_in_dyntaxa)
export(load_shark4r_fields)
export(load_shark4r_stats)
export(lookup_xy)
export(match_algaebase)
export(match_algaebase_genus)
export(match_algaebase_species)
export(match_algaebase_taxa)
export(match_dyntaxa)
export(match_dyntaxa_taxa)
export(match_station)
export(match_taxon_name)
export(match_worms_taxa)
export(match_wormstaxa)
export(nominal_station)
export(parse_scientific_names)
export(plot_map_leaflet)
export(plot_map_leaflet_deliv)
export(positions_are_near_land)
export(read_ptbx)
export(read_shark)
export(read_shark_deliv)
export(run_qc_app)
export(scatterplot)
export(shark_read)
export(shark_read_deliv)
export(shark_read_deliv_xls)
export(shark_read_zip)
export(translate_shark_datatype)
export(update_dyntaxa_taxonomy)
export(update_worms_taxonomy)
export(which_basin)
importFrom(DT,datatable)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,any_of)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,coalesce)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,last)
importFrom(dplyr,last_col)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,rename_with)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylim)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,http_status)
importFrom(httr,progress)
importFrom(httr,status_code)
importFrom(httr,timeout)
importFrom(httr,write_disk)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(leaflet,addAwesomeMarkers)
importFrom(leaflet,addCircleMarkers)
importFrom(leaflet,addCircles)
importFrom(leaflet,addMarkers)
importFrom(leaflet,addProviderTiles)
importFrom(leaflet,addTiles)
importFrom(leaflet,awesomeIcons)
importFrom(leaflet,icons)
importFrom(leaflet,leaflet)
importFrom(leaflet,providerTileOptions)
importFrom(lifecycle,badge)
importFrom(lifecycle,deprecate_stop)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(purrr,map)
importFrom(purrr,map_df)
importFrom(readr,col_character)
importFrom(readr,cols)
importFrom(readr,locale)
importFrom(readr,read_delim)
importFrom(readr,read_tsv)
importFrom(readr,type_convert)
importFrom(readr,write_tsv)
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(readxl,read_xls)
importFrom(readxl,read_xlsx)
importFrom(rlang,.data)
importFrom(sf,st_area)
importFrom(sf,st_as_sf)
importFrom(sf,st_as_sfc)
importFrom(sf,st_bbox)
importFrom(sf,st_crs)
importFrom(sf,st_geometry_type)
importFrom(sf,st_intersects)
importFrom(sf,st_join)
importFrom(sf,st_make_valid)
importFrom(sf,st_read)
importFrom(sf,st_set_crs)
importFrom(sf,st_transform)
importFrom(sf,st_within)
importFrom(sf,st_write)
importFrom(stringi,stri_enc_detect)
importFrom(terra,buffer)
importFrom(terra,crs)
importFrom(terra,vect)
importFrom(tidyr,all_of)
importFrom(tidyr,drop_na)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
importFrom(vroom,vroom)
importFrom(worrms,wm_children)
importFrom(worrms,wm_classification)
importFrom(worrms,wm_name2id_)
importFrom(worrms,wm_record)
importFrom(worrms,wm_records_name)
importFrom(worrms,wm_records_names)
importFrom(worrms,wm_records_taxamatch)
importFrom(worrms,wm_synonyms)
